type HighlightEvent = "onContext";
interface HighlightAPI {
    user: {
        /**
         * Get the facts the user has set for themselves. This could be "I only want concise responses", "my name is...", etc.
         */
        getFacts: () => Promise<string[]>;
    };
    auth: {
        /**
         * Get an access token and refresh token that can be used to validate the user's session on your backend.
         */
        signIn: () => Promise<{
            accessToken: string;
            refreshToken: string;
        }>;
    };
    /**
     * Adds an event listener for your Highlight app.
     * @param event The name of the event to listen for.
     * @param listener The listener Highlight will call when the event is emitted.
     */
    addEventListener: (event: HighlightEvent, listener: (...args: any[]) => void) => void;
}
declare const api: HighlightAPI;

export { type HighlightEvent, api as default };
